summaryrefslogtreecommitdiffstats
path: root/libkonq
diff options
context:
space:
mode:
Diffstat (limited to 'libkonq')
-rw-r--r--libkonq/konq_popupmenu.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkonq/konq_popupmenu.cc b/libkonq/konq_popupmenu.cc
index b878b0ae5..c396bc2c0 100644
--- a/libkonq/konq_popupmenu.cc
+++ b/libkonq/konq_popupmenu.cc
@@ -876,20 +876,20 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
{
KService::Ptr service = (*it);
// Skip OnlyShowIn=Foo and NotShowIn=KDE entries,
// but still offer NoDisplay=true entries, that's the
// whole point of such desktop files. This is why we don't
// use service->noDisplay() here.
const TQString onlyShowIn = service->property("OnlyShowIn", TQVariant::String).toString();
if ( !onlyShowIn.isEmpty() ) {
const TQStringList aList = TQStringList::split(';', onlyShowIn);
- if (!aList.contains("KDE"))
+ if (!aList.contains("TDE"))
continue;
}
const TQString notShowIn = service->property("NotShowIn", TQVariant::String).toString();
if ( !notShowIn.isEmpty() ) {
const TQStringList aList = TQStringList::split(';', notShowIn);
- if (aList.contains("KDE"))
+ if (aList.contains("TDE"))
continue;
}
@@ -876,20 +876,20 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
{
KService::Ptr service = (*it);
- // Skip OnlyShowIn=Foo and NotShowIn=KDE entries,
+ // Skip OnlyShowIn=Foo and NotShowIn=TDE entries,
// but still offer NoDisplay=true entries, that's the
// whole point of such desktop files. This is why we don't